'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _radium = require('radium');

var _radium2 = _interopRequireDefault(_radium);

var _includes = require('lodash/includes');

var _includes2 = _interopRequireDefault(_includes);

var _getStyles = require('./get-styles');

var _getStyles2 = _interopRequireDefault(_getStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var propTypes = {
  /** The CheckboxGroup's values */
  values: _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number, _propTypes2.default.bool])),
  /**
   * Callback fired when Checkbox's value changes
   *
   * function(event: object) => void
   */
  onChange: _propTypes2.default.func.isRequired,
  /** The CheckboxGroup's content (Checkbox), each child must have a value prop */
  children: _propTypes2.default.node.isRequired,
  /** The CheckboxGroup's label */
  label: _propTypes2.default.node.isRequired,
  /** Override the styles of the label element */
  labelStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the root element */
  style: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the button container */
  buttonStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Display an error message */
  error: _propTypes2.default.node,
  /** Override the styles of the error element */
  errorStyle: _propTypes2.default.object // eslint-disable-line react/forbid-prop-types
};

var defaultProps = {
  values: [],
  labelStyle: {},
  style: {},
  error: null,
  errorStyle: {},
  buttonStyle: {}
};

var displayName = 'CheckboxGroup';

var CheckboxGroup = function CheckboxGroup(_ref) {
  var values = _ref.values,
      onChange = _ref.onChange,
      children = _ref.children,
      buttonStyle = _ref.buttonStyle,
      label = _ref.label,
      labelStyle = _ref.labelStyle,
      style = _ref.style,
      error = _ref.error,
      errorStyle = _ref.errorStyle,
      custom = _objectWithoutProperties(_ref, ['values', 'onChange', 'children', 'buttonStyle', 'label', 'labelStyle', 'style', 'error', 'errorStyle']);

  var childrenWithProps = _react2.default.Children.map(children, function (child) {
    return _react2.default.cloneElement(child, {
      checked: (0, _includes2.default)(values, child.props.value),
      onChange: onChange
    });
  });

  return _react2.default.createElement(
    'section',
    _extends({ style: style }, custom),
    _react2.default.createElement(
      'span',
      { style: _getStyles2.default.label(labelStyle) },
      label
    ),
    _react2.default.createElement(
      'section',
      { style: _getStyles2.default.buttons(buttonStyle) },
      childrenWithProps
    ),
    error ? _react2.default.createElement(
      'span',
      { style: _getStyles2.default.error(errorStyle) },
      error
    ) : null
  );
};

CheckboxGroup.propTypes = propTypes;
CheckboxGroup.defaultProps = defaultProps;
CheckboxGroup.displayName = displayName;

exports.default = (0, _radium2.default)(CheckboxGroup);
module.exports = exports.default;