'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _startsWith = require('lodash/startsWith');

var _startsWith2 = _interopRequireDefault(_startsWith);

var _includes = require('lodash/includes');

var _includes2 = _interopRequireDefault(_includes);

var _filter = require('lodash/filter');

var _filter2 = _interopRequireDefault(_filter);

var _reject = require('lodash/reject');

var _reject2 = _interopRequireDefault(_reject);

var _noop = require('lodash/noop');

var _noop2 = _interopRequireDefault(_noop);

var _isEmpty = require('lodash/isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

var _size = require('lodash/size');

var _size2 = _interopRequireDefault(_size);

var _map = require('lodash/map');

var _map2 = _interopRequireDefault(_map);

var _emojione = require('emojione');

var _emojione2 = _interopRequireDefault(_emojione);

var _htmlReactParser = require('html-react-parser');

var _htmlReactParser2 = _interopRequireDefault(_htmlReactParser);

var _reactEventListener = require('react-event-listener');

var _reactEventListener2 = _interopRequireDefault(_reactEventListener);

var _getStyles = require('./get-styles');

var _getStyles2 = _interopRequireDefault(_getStyles);

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

var _emoji = require('../emoji-menu/emoji');

var _emoji2 = _interopRequireDefault(_emoji);

var _emojiModifiers = require('../emoji-menu/emoji-modifiers');

var _emojiModifiers2 = _interopRequireDefault(_emojiModifiers);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var propTypes = {
  /** Filter emoji based on input value */
  value: _propTypes2.default.string.isRequired,
  /** Override the styles of the root element */
  style: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the header element */
  headerStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /**
   * Callback fired when a emoji is selected by pressing 'enter', 'escape' or by clicking the emoji
   *
   * function(event: object, emoji: object) => void
   */
  onSelect: _propTypes2.default.func.isRequired,
  /**
   * Callback fired when a emoji is changed by navigating with the 'arrow keys' or 'tab'
   *
   * function(event: object, emoji: object) => void
   */
  onChange: _propTypes2.default.func.isRequired,
  /**
   * Callback fired when the menu is closed
   *
   * function() => void
   */
  onMenuClose: _propTypes2.default.func,
  /**
   * Callback fired when the menu is opened
   *
   * function() => void
   */
  onMenuOpen: _propTypes2.default.func,
  color: _propTypes2.default.string.isRequired
};

var defaultProps = {
  style: {},
  headerStyle: {},
  onMenuClose: _noop2.default,
  onMenuOpen: _noop2.default
};

/** Used for displaying a list of commands */

var EmojiFilter = function (_Component) {
  _inherits(EmojiFilter, _Component);

  function EmojiFilter(props) {
    _classCallCheck(this, EmojiFilter);

    var _this = _possibleConstructorReturn(this, (EmojiFilter.__proto__ || Object.getPrototypeOf(EmojiFilter)).call(this, props));

    _this.filterEmoji = function (value) {
      var tone = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _this.state.tone;
      // eslint-disable-line react/destructuring-assignment
      if (!value || value.length < 3) {
        return [];
      }

      var filteredEmoji = (0, _reject2.default)((0, _filter2.default)(_emoji2.default, function (icon) {
        return (0, _startsWith2.default)(icon.shortname, value);
      }), function (icon) {
        return icon.diversity && !(0, _includes2.default)(icon.title, tone);
      });

      if (filteredEmoji.length === 1 && (0, _includes2.default)(value, filteredEmoji[0].shortname)) {
        return [];
      }

      return filteredEmoji;
    };

    _this.hideMenu = function () {
      var onMenuClose = _this.props.onMenuClose;
      var open = _this.state.open;


      if (open) {
        _this.setState({ open: false, emoji: [], selectedIndex: 0 });
        onMenuClose();
      }
    };

    _this.handleKeyDown = function (event) {
      var key = event.which || event.keyCode;
      var shiftKey = event.shiftKey;
      var selectedIndex = _this.state.selectedIndex;


      if (key === 27) {
        return _this.hideMenu(event);
      }

      if (key === 39 || key === 40 || key === 9 && !shiftKey) {
        event.preventDefault();
        event.stopImmediatePropagation();
        return _this.selectNext(event);
      }

      if (key === 37 || key === 38 || key === 9 && shiftKey) {
        event.preventDefault();
        event.stopImmediatePropagation();
        return _this.selectPrevious(event);
      }

      if (key === 13) {
        _this.handleSelect(event, _this.state.emoji[selectedIndex], selectedIndex); // eslint-disable-line react/destructuring-assignment
      }

      return false;
    };

    _this.handleClickOutside = function () {
      _this.hideMenu();
    };

    _this.selectNext = function (event) {
      var selectedIndex = _this.state.selectedIndex;

      var emojiSize = (0, _size2.default)(_this.state.emoji); // eslint-disable-line react/destructuring-assignment

      if (selectedIndex === null) {
        return _this.handleChange(event, _this.state.emoji[0], 0); // eslint-disable-line react/destructuring-assignment
      }

      if (selectedIndex + 1 < emojiSize) {
        return _this.handleChange(event, _this.state.emoji[selectedIndex + 1], selectedIndex + 1); // eslint-disable-line react/destructuring-assignment
      }

      if (selectedIndex === emojiSize - 1) {
        return _this.handleChange(event, _this.state.emoji[0], 0); // eslint-disable-line react/destructuring-assignment
      }

      return false;
    };

    _this.selectPrevious = function (event) {
      var selectedIndex = _this.state.selectedIndex;

      var emojiSize = (0, _size2.default)(_this.state.emoji); // eslint-disable-line react/destructuring-assignment

      if (selectedIndex === null) {
        return _this.handleChange(event, _this.state.emoji[0], 0); // eslint-disable-line react/destructuring-assignment
      }

      if (selectedIndex === 0) {
        return _this.handleChange(event, _this.state.emoji[emojiSize - 1], emojiSize - 1); // eslint-disable-line react/destructuring-assignment
      }

      if (selectedIndex - 1 < emojiSize) {
        return _this.handleChange(event, _this.state.emoji[selectedIndex - 1], selectedIndex - 1); // eslint-disable-line react/destructuring-assignment
      }

      return false;
    };

    _this.changeTone = function (tone) {
      var value = _this.props.value;


      _this.setState({
        tone: tone,
        emoji: _this.filterEmoji(value, tone)
      });
    };

    _this.parseHtml = function (html) {
      var options = {
        replace: function replace(domNode) {
          if (domNode.attribs && domNode.attribs.class === 'emojione') {
            var _domNode$attribs = domNode.attribs,
                src = _domNode$attribs.src,
                alt = _domNode$attribs.alt,
                title = _domNode$attribs.title;


            return _react2.default.createElement('img', { src: src, alt: alt, title: title, style: _styles2.default.emojiIcon });
          }

          return domNode;
        }
      };

      return (0, _htmlReactParser2.default)(html, options);
    };

    _this.handleSelect = function (event, icon, index) {
      var onSelect = _this.props.onSelect;


      _this.setState({ selectedIndex: index });
      onSelect(event, icon);
    };

    _this.handleChange = function (event, icon, index) {
      var onChange = _this.props.onChange;


      _this.setState({ selectedIndex: index });
      onChange(event, icon);
    };

    _this.state = {
      open: false,
      emoji: [],
      tone: 'tone0',
      selectedIndex: null
    };
    return _this;
  }

  _createClass(EmojiFilter, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      var value = nextProps.value;
      var open = this.state.open;
      var onMenuOpen = this.props.onMenuOpen;


      if (!value) {
        return this.hideMenu();
      }

      var filteredEmoji = this.filterEmoji(nextProps.value);

      if (!(0, _isEmpty2.default)(filteredEmoji) && !open) {
        this.setState({
          open: true,
          emoji: filteredEmoji
        });
        return onMenuOpen();
      }

      if ((0, _isEmpty2.default)(filteredEmoji) && open) {
        return this.hideMenu();
      }

      return this.setState({
        emoji: filteredEmoji
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          value = _props.value,
          onSelect = _props.onSelect,
          style = _props.style,
          headerStyle = _props.headerStyle,
          eventTypes = _props.eventTypes,
          outsideClickIgnoreClass = _props.outsideClickIgnoreClass,
          preventDefault = _props.preventDefault,
          stopPropagation = _props.stopPropagation,
          disableOnClickOutside = _props.disableOnClickOutside,
          enableOnClickOutside = _props.enableOnClickOutside,
          onMenuClose = _props.onMenuClose,
          onMenuOpen = _props.onMenuOpen,
          color = _props.color,
          custom = _objectWithoutProperties(_props, ['value', 'onSelect', 'style', 'headerStyle', 'eventTypes', 'outsideClickIgnoreClass', 'preventDefault', 'stopPropagation', 'disableOnClickOutside', 'enableOnClickOutside', 'onMenuClose', 'onMenuOpen', 'color']);

      var _state = this.state,
          open = _state.open,
          tone = _state.tone,
          selectedIndex = _state.selectedIndex;


      if (!open) {
        return null;
      }

      var modifiers = (0, _filter2.default)(_emoji2.default, { category: 'modifier' });

      return _react2.default.createElement(
        'section',
        _extends({ style: _getStyles2.default.root(style) }, custom),
        _react2.default.createElement(_emojiModifiers2.default, {
          modifiers: modifiers,
          changeTone: this.changeTone,
          tone: tone,
          style: _getStyles2.default.header(headerStyle)
        }),
        _react2.default.createElement(
          'section',
          { style: _getStyles2.default.commands() },
          (0, _map2.default)(this.state.emoji, function (icon, index) {
            return (// eslint-disable-line
              _react2.default.createElement(
                'div',
                {
                  key: icon.shortname,
                  style: _getStyles2.default.emoji(color, index === selectedIndex),
                  onMouseOver: function onMouseOver(event) {
                    return _this2.handleChange(event, icon, index);
                  },
                  onClick: function onClick(event) {
                    return _this2.handleSelect(event, icon, index);
                  }
                },
                _this2.parseHtml(_emojione2.default.toImage(icon.shortname)),
                icon.shortname
              )
            );
          })
        ),
        _react2.default.createElement(_reactEventListener2.default, { target: 'window', onKeyDown: this.handleKeyDown })
      );
    }
  }]);

  return EmojiFilter;
}(_react.Component);

EmojiFilter.displayName = 'EmojiFilter';
EmojiFilter.propTypes = propTypes;
EmojiFilter.defaultProps = defaultProps;

exports.default = EmojiFilter;
module.exports = exports.default;