'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _map = require('lodash/map');

var _map2 = _interopRequireDefault(_map);

var _isEmpty = require('lodash/isEmpty');

var _isEmpty2 = _interopRequireDefault(_isEmpty);

var _size = require('lodash/size');

var _size2 = _interopRequireDefault(_size);

var _noop = require('lodash/noop');

var _noop2 = _interopRequireDefault(_noop);

var _reactEventListener = require('react-event-listener');

var _reactEventListener2 = _interopRequireDefault(_reactEventListener);

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

var _getStyles = require('./get-styles');

var _getStyles2 = _interopRequireDefault(_getStyles);

var _lightbox = require('../lightbox');

var _lightbox2 = _interopRequireDefault(_lightbox);

var _imageLoader = require('../image-loader');

var _imageLoader2 = _interopRequireDefault(_imageLoader);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var displayName = 'Gallery';

var propTypes = {
  /**
   * Array of objects containing gallery images.
   * Each object must have a 'src' key.
   * 'alt', 'placeholder', 'placeholderType', 'width', 'height' and 'title' are optional
   * Color placeholders only work if both 'width' and 'height' are set
   */
  items: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    src: _propTypes2.default.string.isRequired,
    alt: _propTypes2.default.string,
    placeholder: _propTypes2.default.string,
    placeholderType: _propTypes2.default.oneOf(['image', 'color']),
    width: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
    height: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
    title: _propTypes2.default.node
  })).isRequired,
  /** Gallery row height */
  rowHeight: _propTypes2.default.number,
  /**
   * Callback fired when a Gallery's item is clicked, only works if enableLightbox equals false
   *
   * function(event: object, image: object) => void
   */
  onItemClick: _propTypes2.default.func,
  /** Override the styles of the root element */
  style: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the image container element */
  itemContainerStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the image element */
  itemStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Open a Lightbox when an item is clicked */
  enableLightbox: _propTypes2.default.bool,
  /** Image placeholder url */
  imagePlaceholder: _propTypes2.default.string,
  /** Image error url */
  imageError: _propTypes2.default.string
};

var defaultProps = {
  rowHeight: 320,
  onItemClick: _noop2.default,
  style: {},
  itemContainerStyle: {},
  itemStyle: {},
  enableLightbox: false,
  imagePlaceholder: 'https://cdn.anchor.fish/client/assets/defaults/picture.f682bf93.jpg',
  imageError: 'https://cdn.anchor.fish/client/assets/defaults/error.2838da1f.jpg'
};

/** Justified grid layout for showcasing images. */

var Gallery = function (_Component) {
  _inherits(Gallery, _Component);

  function Gallery() {
    _classCallCheck(this, Gallery);

    var _this = _possibleConstructorReturn(this, (Gallery.__proto__ || Object.getPrototypeOf(Gallery)).call(this));

    _this.showLightbox = function (item, index) {
      _this.setState({
        lightbox: item,
        selectedIndex: index
      });
    };

    _this.hideLightbox = function () {
      _this.setState({
        lightbox: {}
      });
    };

    _this.handleKeyUp = function (event) {
      var key = event.which || event.keyCode;
      var lightbox = _this.state.lightbox;


      if ((0, _isEmpty2.default)(lightbox)) {
        return false;
      }

      if (key === 39) {
        event.preventDefault();
        event.stopImmediatePropagation();
        return _this.selectNext();
      }

      if (key === 37) {
        event.preventDefault();
        event.stopImmediatePropagation();
        return _this.selectPrevious();
      }

      return false;
    };

    _this.selectNext = function () {
      var items = _this.props.items;
      var selectedIndex = _this.state.selectedIndex;

      var gallerySize = (0, _size2.default)(items);
      var newIndex = selectedIndex + 1;

      if (newIndex < gallerySize) {
        return _this.showLightbox(items[newIndex], newIndex);
      }

      if (newIndex === gallerySize) {
        return _this.showLightbox(items[0], 0);
      }

      return false;
    };

    _this.selectPrevious = function () {
      var items = _this.props.items;
      var selectedIndex = _this.state.selectedIndex;

      var gallerySize = (0, _size2.default)(items);
      var newIndex = selectedIndex - 1;

      if (selectedIndex === 0) {
        return _this.showLightbox(items[gallerySize - 1], gallerySize - 1);
      }

      if (newIndex < gallerySize) {
        return _this.showLightbox(items[newIndex], newIndex);
      }

      return false;
    };

    _this.state = {
      lightbox: {},
      selectedIndex: 0
    };
    return _this;
  }

  _createClass(Gallery, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          items = _props.items,
          rowHeight = _props.rowHeight,
          onItemClick = _props.onItemClick,
          style = _props.style,
          itemContainerStyle = _props.itemContainerStyle,
          itemStyle = _props.itemStyle,
          enableLightbox = _props.enableLightbox,
          imagePlaceholder = _props.imagePlaceholder,
          imageError = _props.imageError,
          custom = _objectWithoutProperties(_props, ['items', 'rowHeight', 'onItemClick', 'style', 'itemContainerStyle', 'itemStyle', 'enableLightbox', 'imagePlaceholder', 'imageError']);

      var lightbox = this.state.lightbox;


      var imgProps = {
        style: _getStyles2.default.item(rowHeight, itemStyle)
      };

      var error = _react2.default.createElement('img', { style: _getStyles2.default.item(rowHeight, itemStyle), src: imageError, alt: 'error' });

      return _react2.default.createElement(
        'section',
        _extends({ style: _getStyles2.default.root(style) }, custom),
        (0, _map2.default)(items, function (item, index) {
          var onClick = function onClick(event) {
            return onItemClick(event, item);
          };

          if (enableLightbox) {
            onClick = function onClick() {
              return _this2.showLightbox(item, index);
            };
          }

          var placeholder = _react2.default.createElement('img', {
            style: _getStyles2.default.item(rowHeight, itemStyle),
            src: item.placeholder || imagePlaceholder,
            alt: 'placeholder'
          });

          if (item.placeholder && item.placeholderType === 'color' && item.width && item.height) {
            placeholder = _react2.default.createElement('div', {
              style: _getStyles2.default.colorPlaceholder(item.placeholder, item.width, item.height, rowHeight, itemStyle)
            });
          }

          return _react2.default.createElement(
            'div',
            {
              style: _getStyles2.default.itemContainer(rowHeight, enableLightbox, itemContainerStyle),
              key: 'gallery-' + index,
              onClick: onClick
            },
            _react2.default.createElement(_imageLoader2.default, {
              src: item.src,
              alt: item.alt || item.src,
              imgProps: imgProps,
              placeholder: placeholder,
              error: error
            })
          );
        }),
        _react2.default.createElement('div', { style: _styles2.default.after }),
        enableLightbox && !(0, _isEmpty2.default)(lightbox) ? _react2.default.createElement(_lightbox2.default, {
          open: !(0, _isEmpty2.default)(lightbox),
          image: lightbox.src,
          title: lightbox.title,
          hideLightbox: this.hideLightbox
        }) : null,
        _react2.default.createElement(_reactEventListener2.default, { target: 'window', onKeyUp: this.handleKeyUp })
      );
    }
  }]);

  return Gallery;
}(_react.Component);

Gallery.displayName = displayName;
Gallery.propTypes = propTypes;
Gallery.defaultProps = defaultProps;

exports.default = Gallery;
module.exports = exports.default;