'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _size = require('lodash/size');

var _size2 = _interopRequireDefault(_size);

var _range = require('lodash/range');

var _range2 = _interopRequireDefault(_range);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var pager = function pager(list) {
  var currentPage = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  var pageSize = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 10;

  // 10 page links shown at any time (e.g. 1 2 3 4 5 6 7 8 9 10)
  // unless there are less than 10 total pages

  // the active link (current page) is in the 6th position,
  // except for when the active link is below 6 or less than 4 from the last position

  var totalItems = (0, _size2.default)(list);
  var totalPages = Math.ceil(totalItems / pageSize);

  var startPage = 1;
  var endPage = totalPages;

  if (totalPages > 10) {
    if (currentPage <= 6) {
      endPage = 10;
    } else if (currentPage + 4 >= totalPages) {
      startPage = totalPages - 9;
    } else {
      startPage = currentPage - 5;
      endPage = currentPage + 4;
    }
  }

  var startIndex = (currentPage - 1) * pageSize;
  var endIndex = Math.min(startIndex + (pageSize - 1), totalItems - 1);

  var pages = (0, _range2.default)(startPage, endPage + 1);

  return {
    totalItems: totalItems,
    currentPage: currentPage,
    pageSize: pageSize,
    totalPages: totalPages,
    startPage: startPage,
    endPage: endPage,
    startIndex: startIndex,
    endIndex: endIndex,
    pages: pages
  };
};

exports.default = pager;
module.exports = exports.default;