'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _radium = require('radium');

var _radium2 = _interopRequireDefault(_radium);

var _compose = require('recompose/compose');

var _compose2 = _interopRequireDefault(_compose);

var _colors = require('../settings/colors');

var _colors2 = _interopRequireDefault(_colors);

var _iconRadio = require('../icons/icon-radio');

var _iconRadio2 = _interopRequireDefault(_iconRadio);

var _getStyles = require('./get-styles');

var _getStyles2 = _interopRequireDefault(_getStyles);

var _themeable = require('../themeable');

var _themeable2 = _interopRequireDefault(_themeable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var propTypes = {
  /** The input's value */
  value: _propTypes2.default.string.isRequired,
  /** The input's label text */
  label: _propTypes2.default.node.isRequired,
  /**
   * Callback fired when RadioButton's value changes
   *
   * function(event: object) => void
   */
  onChange: _propTypes2.default.func,
  /** Input active */
  checked: _propTypes2.default.bool,
  /** Override the styles of the root element */
  style: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the input element */
  inputStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the icon element */
  iconStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the label element */
  labelStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the label element */
  icon: _propTypes2.default.node,
  color: _propTypes2.default.string.isRequired
};

var defaultProps = {
  style: {},
  inputStyle: {},
  iconStyle: {},
  labelStyle: {},
  checked: false,
  onChange: null,
  icon: null
};

var displayName = 'RadioButton';

/** Radio buttons are switches used for selection from multiple options */
var RadioButton = function RadioButton(_ref) {
  var value = _ref.value,
      label = _ref.label,
      style = _ref.style,
      inputStyle = _ref.inputStyle,
      iconStyle = _ref.iconStyle,
      labelStyle = _ref.labelStyle,
      onChange = _ref.onChange,
      checked = _ref.checked,
      color = _ref.color,
      icon = _ref.icon,
      custom = _objectWithoutProperties(_ref, ['value', 'label', 'style', 'inputStyle', 'iconStyle', 'labelStyle', 'onChange', 'checked', 'color', 'icon']);

  return _react2.default.createElement(
    'label',
    { key: 'radio', htmlFor: value, style: _getStyles2.default.root(color, style) },
    _react2.default.createElement('input', _extends({
      type: 'radio',
      value: value,
      id: value,
      onChange: onChange,
      checked: checked,
      style: _getStyles2.default.input(inputStyle)
    }, custom)),
    _react2.default.createElement(
      'div',
      { style: _getStyles2.default.icon(iconStyle) },
      icon || _react2.default.createElement(_iconRadio2.default, { color: checked ? color || _colors2.default.theme : _colors2.default.icons })
    ),
    _react2.default.createElement(
      'span',
      { style: _getStyles2.default.label(labelStyle) },
      label
    )
  );
};

RadioButton.propTypes = propTypes;
RadioButton.defaultProps = defaultProps;
RadioButton.displayName = displayName;

var enhance = (0, _compose2.default)((0, _themeable2.default)(), _radium2.default);

exports.default = enhance(RadioButton);
module.exports = exports.default;