'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _radium = require('radium');

var _debounce = require('lodash/debounce');

var _debounce2 = _interopRequireDefault(_debounce);

var _iconSearch = require('../icons/icon-search');

var _iconSearch2 = _interopRequireDefault(_iconSearch);

var _getStyles = require('./get-styles');

var _getStyles2 = _interopRequireDefault(_getStyles);

var _colors = require('../settings/colors');

var _colors2 = _interopRequireDefault(_colors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var displayName = 'SearchBox';

var propTypes = {
  /**
   * Callback fired when SearchBox's value changes
   *
   * function(event: object) => void
   */
  onChange: _propTypes2.default.func.isRequired,
  /**
   * Callback fired when SearchBox's query changes, with debounce
   *
   * function(query: string) => void
   */
  changeSearchQuery: _propTypes2.default.func.isRequired,
  /** The input's value */
  value: _propTypes2.default.string.isRequired,
  /** The input's placeholder */
  placeholder: _propTypes2.default.node,
  /** Override the styles of the root element */
  style: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the input element */
  inputStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the icon element */
  iconStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the input's placeholder */
  placeholderStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** The search's icon color */
  iconColor: _propTypes2.default.string,
  /** Add a ref to the input element */
  inputRef: _propTypes2.default.func
};

var defaultProps = {
  style: {},
  inputStyle: {},
  iconStyle: {},
  placeholder: 'Search something...',
  placeholderStyle: {},
  iconColor: _colors2.default.icons,
  inputRef: null
};

/** General purpose Search box */

var SearchBox = function (_Component) {
  _inherits(SearchBox, _Component);

  function SearchBox(props) {
    _classCallCheck(this, SearchBox);

    var _this = _possibleConstructorReturn(this, (SearchBox.__proto__ || Object.getPrototypeOf(SearchBox)).call(this, props));

    _this.handleChange = _this.handleChange.bind(_this);
    _this.changeSearchQuery = (0, _debounce2.default)(_this.changeSearchQuery.bind(_this), 300, false);
    return _this;
  }

  _createClass(SearchBox, [{
    key: 'changeSearchQuery',
    value: function changeSearchQuery(event) {
      var changeSearchQuery = this.props.changeSearchQuery;


      changeSearchQuery(event);
    }
  }, {
    key: 'handleChange',
    value: function handleChange(event) {
      var onChange = this.props.onChange;


      onChange(event);
      this.changeSearchQuery(event.currentTarget.value);
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          value = _props.value,
          placeholder = _props.placeholder,
          style = _props.style,
          inputStyle = _props.inputStyle,
          iconStyle = _props.iconStyle,
          changeSearchQuery = _props.changeSearchQuery,
          onChange = _props.onChange,
          placeholderStyle = _props.placeholderStyle,
          iconColor = _props.iconColor,
          inputRef = _props.inputRef,
          custom = _objectWithoutProperties(_props, ['value', 'placeholder', 'style', 'inputStyle', 'iconStyle', 'changeSearchQuery', 'onChange', 'placeholderStyle', 'iconColor', 'inputRef']);

      return _react2.default.createElement(
        'section',
        _extends({ style: _getStyles2.default.root(style) }, custom),
        _react2.default.createElement(
          'div',
          { style: _getStyles2.default.icon(iconStyle) },
          _react2.default.createElement(_iconSearch2.default, { color: iconColor })
        ),
        _react2.default.createElement('input', {
          style: _getStyles2.default.input(inputStyle),
          value: value,
          onChange: this.handleChange,
          placeholder: placeholder,
          className: 'search-box',
          ref: inputRef
        }),
        _react2.default.createElement(_radium.Style, {
          rules: {
            '.search-box::placeholder': _getStyles2.default.placeholder(placeholderStyle)
          }
        })
      );
    }
  }]);

  return SearchBox;
}(_react.Component);

SearchBox.displayName = displayName;
SearchBox.propTypes = propTypes;
SearchBox.defaultProps = defaultProps;

exports.default = SearchBox;
module.exports = exports.default;