'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

var _getStyles = require('./get-styles');

var _getStyles2 = _interopRequireDefault(_getStyles);

var _getPercentage = require('../internal/get-percentage');

var _getPercentage2 = _interopRequireDefault(_getPercentage);

var _propTypes3 = require('../internal/prop-types');

var _propTypes4 = _interopRequireDefault(_propTypes3);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var propTypes = {
  /**
   * Callback fired when Slider's value changes
   *
   * function(event: object) => void
   */
  onChange: _propTypes2.default.func.isRequired,
  /** The slider's value. Must between min and max */
  value: _propTypes4.default.valueInRange,
  /** The slider's label */
  label: _propTypes2.default.node.isRequired,
  /** The slider's name */
  name: _propTypes2.default.string.isRequired,
  /** The slider's max value. Cannot be equal to min. */
  max: _propTypes4.default.minMax,
  /** The slider's min value. Cannot be equal to max. */
  min: _propTypes4.default.minMax,
  /** The slider's step value */
  step: _propTypes2.default.number,
  /** Disables the slider */
  disabled: _propTypes2.default.bool,
  /** Display an error message */
  error: _propTypes2.default.node,
  /** Override the styles of the error element */
  errorStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the root element */
  style: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  /** Override the styles of the label element */
  labelStyle: _propTypes2.default.object, // eslint-disable-line react/forbid-prop-types
  color: _propTypes2.default.string.isRequired
};

var defaultProps = {
  max: 1,
  min: 0,
  value: 0,
  step: null,
  disabled: false,
  error: null,
  errorStyle: {},
  style: {},
  labelStyle: {}
};

var displayName = 'Slider';

/** General purpose form slider */
var Slider = function Slider(_ref) {
  var name = _ref.name,
      label = _ref.label,
      onChange = _ref.onChange,
      value = _ref.value,
      max = _ref.max,
      min = _ref.min,
      step = _ref.step,
      disabled = _ref.disabled,
      errorStyle = _ref.errorStyle,
      error = _ref.error,
      style = _ref.style,
      labelStyle = _ref.labelStyle,
      color = _ref.color,
      custom = _objectWithoutProperties(_ref, ['name', 'label', 'onChange', 'value', 'max', 'min', 'step', 'disabled', 'errorStyle', 'error', 'style', 'labelStyle', 'color']);

  var percentage = (0, _getPercentage2.default)(value, min, max);

  return _react2.default.createElement(
    'section',
    { style: _getStyles2.default.root(style, disabled) },
    _react2.default.createElement(
      'label',
      { style: _getStyles2.default.label(labelStyle), htmlFor: name },
      label
    ),
    _react2.default.createElement(
      'div',
      { style: _styles2.default.sliderRoot },
      _react2.default.createElement(
        'div',
        { style: _styles2.default.slider },
        _react2.default.createElement('div', { style: _getStyles2.default.filled(color, percentage) }),
        _react2.default.createElement('div', { style: _getStyles2.default.remaining(percentage) }),
        _react2.default.createElement('div', { style: _getStyles2.default.button(color, percentage) })
      ),
      _react2.default.createElement('input', _extends({
        style: _styles2.default.input,
        onChange: onChange,
        value: value,
        type: 'range',
        max: max,
        min: min,
        id: name,
        step: step,
        disabled: disabled
      }, custom))
    ),
    error ? _react2.default.createElement(
      'span',
      { style: _getStyles2.default.error(errorStyle) },
      error
    ) : null
  );
};

Slider.propTypes = propTypes;
Slider.defaultProps = defaultProps;
Slider.displayName = displayName;

exports.default = Slider;
module.exports = exports.default;