'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _isFinite = require('lodash/isFinite');

var _isFinite2 = _interopRequireDefault(_isFinite);

var _colors = require('../settings/colors');

var _colors2 = _interopRequireDefault(_colors);

var _combineStyles = require('../internal/combine-styles');

var _combineStyles2 = _interopRequireDefault(_combineStyles);

var _styles = require('./styles');

var _styles2 = _interopRequireDefault(_styles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var root = function root(overrideStyle, disabled) {
  var style = _styles2.default.root;

  if (disabled) {
    style = (0, _combineStyles2.default)(style, _styles2.default.disabled);
  }

  return (0, _combineStyles2.default)(style, overrideStyle);
};

var label = function label(overrideStyle) {
  return (0, _combineStyles2.default)(_styles2.default.label, overrideStyle);
};

var filled = function filled() {
  var color = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _colors2.default.theme;
  var percentage = arguments[1];
  var overrideStyle = arguments[2];

  var style = (0, _combineStyles2.default)(_styles2.default.filled, {
    width: (0, _isFinite2.default)(percentage) && percentage > 0 ? percentage * 100 + '%' : '0%',
    backgroundColor: color
  });

  return (0, _combineStyles2.default)(style, overrideStyle);
};

var remaining = function remaining(percentage, overrideStyle) {
  var style = (0, _combineStyles2.default)(_styles2.default.remaining, { width: (1 - percentage) * 100 + '%' });

  return (0, _combineStyles2.default)(style, overrideStyle);
};

var button = function button() {
  var color = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : _colors2.default.theme;
  var percentage = arguments[1];
  var overrideStyle = arguments[2];

  var style = (0, _combineStyles2.default)(_styles2.default.button, {
    left: (0, _isFinite2.default)(percentage) && percentage > 0 ? percentage * 100 + '%' : '0%'
  });

  if (percentage !== 0) {
    style = (0, _combineStyles2.default)(style, { backgroundColor: color, border: '2px solid ' + color });
  }

  return (0, _combineStyles2.default)(style, overrideStyle);
};

var error = function error(overrideStyle) {
  return (0, _combineStyles2.default)(_styles2.default.error, overrideStyle);
};

exports.default = {
  root: root,
  label: label,
  filled: filled,
  remaining: remaining,
  button: button,
  error: error
};
module.exports = exports.default;